# tantri - generating telegraph noise 

Named as an oblique half-pun on both tantri as a form of generating, and tantri as a telegraph or wire.

## dev

Build with `just`, preferred over `do.sh` I think.

## CLI

the json files for dots and dipoles have a specific format that ignores extraneous data but is sad about missing fields.